pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
environment_name: impl Into<String>,
) -> RequestBuilder
pub fn list( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, environment_name: impl Into<String>, ) -> RequestBuilder
Get the Java Components for a managed environment.
Arguments:
subscription_id: The ID of the target subscription. The value must be an UUID.resource_group_name: The name of the resource group. The name is case insensitive.environment_name: Name of the Managed Environment.
Sourcepub fn get(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
environment_name: impl Into<String>,
name: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, environment_name: impl Into<String>, name: impl Into<String>, ) -> RequestBuilder
Get a Java Component.
Arguments:
subscription_id: The ID of the target subscription. The value must be an UUID.resource_group_name: The name of the resource group. The name is case insensitive.environment_name: Name of the Managed Environment.name: Name of the Java Component.
Sourcepub fn create_or_update(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
environment_name: impl Into<String>,
name: impl Into<String>,
java_component_envelope: impl Into<JavaComponent>,
) -> RequestBuilder
pub fn create_or_update( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, environment_name: impl Into<String>, name: impl Into<String>, java_component_envelope: impl Into<JavaComponent>, ) -> RequestBuilder
Creates or updates a Java Component. Creates or updates a Java Component in a Managed Environment.
Arguments:
subscription_id: The ID of the target subscription. The value must be an UUID.resource_group_name: The name of the resource group. The name is case insensitive.environment_name: Name of the Managed Environment.name: Name of the Java Component.java_component_envelope: Configuration details of the Java Component.
Sourcepub fn update(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
environment_name: impl Into<String>,
name: impl Into<String>,
java_component_envelope: impl Into<JavaComponent>,
) -> RequestBuilder
pub fn update( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, environment_name: impl Into<String>, name: impl Into<String>, java_component_envelope: impl Into<JavaComponent>, ) -> RequestBuilder
Update properties of a Java Component Patches a Java Component using JSON Merge Patch
Arguments:
subscription_id: The ID of the target subscription. The value must be an UUID.resource_group_name: The name of the resource group. The name is case insensitive.environment_name: Name of the Managed Environment.name: Name of the Java Component.java_component_envelope: Configuration details of the Java Component.
Sourcepub fn delete(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
environment_name: impl Into<String>,
name: impl Into<String>,
) -> RequestBuilder
pub fn delete( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, environment_name: impl Into<String>, name: impl Into<String>, ) -> RequestBuilder
Delete a Java Component. Delete a Java Component.
Arguments:
subscription_id: The ID of the target subscription. The value must be an UUID.resource_group_name: The name of the resource group. The name is case insensitive.environment_name: Name of the Managed Environment.name: Name of the Java Component.